@@ -30,11 +30,16 @@
 #include <glib.h>
 
 #include "pangowin32.h"
-#include "pango-engine.h"
-#include "pango-utils.h"
 
 extern HFONT _pango_win32_font_get_hfont (PangoFont *font);
 
+#ifndef PANGO_MODULE_PREFIX
+#define PANGO_MODULE_PREFIX _pango_basic_win32
+#endif
+
+#include "pango-engine.h"
+#include "pango-utils.h"
+
 /* No extra fields needed */
 typedef PangoEngineShape      BasicEngineWin32;
 typedef PangoEngineShapeClass BasicEngineWin32Class ;
